#
#
#  Example demonstrating the combination of Blender and ASE
#  ========================================================
#
#
#  Start       : 2012-10-16
#  Last change : 2012-10-31
#  Author      : Clemens Barth (barth@root-1.de) 
#
#
#
#
#  This script has to be executed in a terminal with:
#
#         > python example3.py
#
#  After, push "0" on the number pad. You will then see the atoms 
#  from the camera point of view. 
#
#  Notes
#  =====
#  
#  1. You do not have to install the Atomic Blender - XYZ addon!
#
#  2. More details about the options see:
#     http://wiki.blender.org/index.php/Extensions:2.6/Py/Scripts/Import-Export/XYZ
#
# 




from ase.lattice.surface import *
from ase.io import write
from ase.io import read
from ase import Atoms
from numpy import array
from math import pi, cos, sin
import os

# This is the Blender library
from ase.blender import blend_show, blend_render



filepath = "ase_blender_cluster.xyz"

# Call Blender with all the options from above
blend_render(filepath, "ase_blender_example3.blend", "ase_blender_example3", 
             image_format="PNG",
             blender_close = True)                        




                        
"""
Function: blend_render(slab, file_blend, file_img_mov, **kwargs)
    
slab                     # Either a 'Atom' structure or path to a xyz 
                         # ASCII file. Blender accepts xyz files with several 
                         # frames, which can be used for animations.
                         
file_blend               # This is the Blender file, in which the scene is saved
                         # to.

file_img_mov             # This is the image or movie file name



**kwargs, optional (all values are default values!)
===================================================
mesh = False             # Use mesh balls instead of NURBS
mesh_azimuth = 32        # If mesh balls, number of sectors in azimut
mesh_zenith = 32         # If mesh balls, number of sectors in zenith
scale_ballradius = 1.0   # Scale factor to scalle all atom radii
atomradius = "1"         # Atom radii: '0' pre-defined (default atomic radii)
                         #             '1' atomic radii
                         #             '2' van der Waals
scale_distances = 1.0    # Scale factor to scalle all distances
use_center = True        # Center the atomic structure into the center (0,0,0)
                         # of the world
use_center_all = True    # ...
use_camera = False       # Use a camera. The camera is placed into a distance
                         # such that the atomic structure can be well seen from
                         # the camera. Push '0' on the number pad after Blender 
                         # has loaded the structure. You see the structure from 
                         # the camera point of view
use_lamp = True          # Use also a point light source 
load_frames = False      # Load the frames, if present
frame_skip = 0           # Skip each nth frame.      
frame_delta = 1          # Introduce more frames between each pair of frames,
                         # and interpolate the movement. frame_delta = 1: means 
                         # no additional frames.
blender_close" = False   # Close Blender after having opened. This is important 
                         # for the rendering without the Blender UI opened.
blender_save_file" = ""  # Save the Blender scene into a Blender .blend file. 
                         # This will be always done if the string is not empty.
image_format = "PNG"     # Image/movie format (AVIRAW AVIJPEG PNG BMP).                         
frame_start = 1          # Render from frame 'start' to ...
frame_end   = 1          # ... frame 'end'


For more details: 
http://wiki.blender.org/index.php/Extensions:2.6/Py/Scripts/Import-Export/XYZ
"""                    
                        
 
    
    
    
    
    
    
